package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````=2(```````!``````````""Q````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````9`````````!D``````````0`````````!````
M!````````````````````````````````````*@8````````J!@`````````
M$`````````$````%`````"``````````(``````````@````````GCL`````
M``">.P`````````0`````````0````0`````8`````````!@`````````&``
M``````!H1P```````&A'`````````!`````````!````!@```-BK````````
MV+L```````#8NP```````$@$````````V`0`````````$`````````(````&
M````$*P````````0O````````!"\````````X`$```````#@`0````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````"0`````````)``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``"@H````````*"@````````H*````````#L`````````.P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````V*L```````#8NP```````-B[````
M````*`0````````H!`````````$`````````+VQI8B]L9"UM=7-L+7@X-E\V
M-"YS;RXQ```````````$````(`````4```!'3E4``0`!P`0````)````````
M``(``<`$`````0`````````$````%`````,```!'3E4`T77\QF5T\%/O<++L
M'+'DE^B6*?\`````$0```$`````$````"````"`<$``%0`2"*``0!("&`(2"
MH0`B20($";B"&$&Z!`(*0````$$```!%````20```$H```!1````4@```%0`
M````````6````%D```!:````6P```%P```!>``````````````"CZ1D$SMY'
M+6[%WQ]J?YI\Z]/O#B[%F[:XC?$.(/_D#M5DU'S9<5@<L@&+;YA/PYO"Y3\L
M0OK7A_JA;&"ZXY)\XT?&`57#/-)FK\QFQ;F<0(@'<-/$B060./*+'$-%U>PS
M8MOM%8PES*?=HVM_J9R;X*<""FL:GE"BX/M)"XH05P``````````````````
M``````````````````!V`@``$@````````````````````````";`0``$@``
M``````````````````````!2````$@````````````````````````"\`@``
M$@````````````````````````!O`0``$@`````````````````````````]
M````$@`````````````````````````9`0``$@``````````````````````
M``#>`0``$@````````````````````````"J````$@``````````````````
M``````"S````(@`````````````````````````X`0``$@``````````````
M``````````##`0``$@````````````````````````!D`@``$@``````````
M``````````````"``0``$@````````````````````````#\````$@``````
M``````````````````!]`@``$@`````````````````````````W````$@``
M```````````````````````G`0``$@````````````````````````!-`@``
M$@````````````````````````!B````$@````````````````````````#]
M`0``$@````````````````````````";````$@``````````````````````
M```D`@``$@`````````````````````````?````(```````````````````
M``````!-`0``$@````````````````````````#=````(```````````````
M``````````!J````$@````````````````````````#W````$@``````````
M``````````````!:````$@````````````````````````!+````$@``````
M```````````````````0````$@`````````````````````````;`@``$@``
M``````````````````````"4`@``$@````````````````````````"/`0``
M$@````````````````````````!Y````(`````````````````````````"-
M`@``$@`````````````````````````]`@``$@``````````````````````
M``#J`0``$@`````````````````````````!````$@``````````````````
M``````!$````$@````````````````````````#R`P``$@``````````````
M```````````O`@``$@````````````````````````"%`@``$@``````````
M```````````````+`@``$@````````````````````````!K````$@``````
M``````````````````!K`@``$@`````````````````````````8````$@``
M```````````````````````"`0``$@````````````````````````#8````
M$@````````````````````````!<`0``%@````````````````````````";
M`@``$@````````````````````````"J`@``$@``````````````````````
M```@`0``$@````````````````````````"5````$@``````````````````
M``````"C````$@````````````````````````!P````$@``````````````
M```````````_`0``$@````````````````````````!8`@``$@``````````
M```````````````3`0``$@````````````````````````#"````(```````
M``````````````````#4`0``$@````````````````````````":````$@``
M``````````````````````#9`0``$@````````````````````````#%`@``
M(0`6`"#`````````"`````````!Z`P``$@`+`!`V````````]`8```````"'
M`P``$@`+`'`_````````T@````````"W`@``$@`+`&`@````````%0(`````
M``"P`0``$@`,`)M;`````````0````````#^`@``$@`+`*`J````````!0``
M``````#^`P``$@`)```@`````````0`````````S`P``$@`+`+`J````````
M/P(```````!(`P``$@`+`!`]````````4P(```````"3`P``$``6`"#`````
M```````````````9`P``$@`+`*`R````````8@````````!``P``$@`+`!`S
M````````L0````````!>`P``$@`+`$`I````````)@````````!O`P``$@`+
M`!!7````````/P(```````"?`P``$@`+`$`U````````Q0````````#.`P``
M$``6`+#```````````````````#3`P``$@`+`/`L````````)`````````!F
M`P``$@`+`(LB````````(P`````````G`P``$@`+`"`M````````$@$`````
M``#&`@``$0`6`"#`````````"``````````/`P``$0`5`!C`````````"```
M``````#'`@``(0`6`"#`````````"``````````)````$0`2``B\````````
M"`````````#'`P``$``5`"#```````````````````"8`P``$``+`'4B````
M``````````````#[`P``$@`+`,!6````````1@````````#(`@``(0`6`"#`
M````````"`````````#@`P``$@`+`"`U````````'P````````"Q`P``$@`+
M`'`I````````*@$````````$!```$@`+`%!9````````2P(```````#Q`@``
M$@`+`$`N````````700```````"V`0``$0`6`"C``````````0``````````
M;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`7U]D97)E9VES=&5R7V9R
M86UE7VEN9F\`;'-E96L`9V5T<&ED`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S
M=')N8VUP`'-T<G)C:'(`;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`=F9P<FEN=&8`<W1R8VAR`')E861L:6YK`%]?
M8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T
M:6]N`&UK9&ER`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U
M:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O
M;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E
M=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``
M4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A
M=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E
M<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S
M=')C<'D`<F5A9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A
M=&9O<FL`7U]L:6)C7W-T87)T7VUA:6X`<VYP<FEN=&8`7U]?96YV:7)O;@!L
M:6)P97)L+G-O`&QI8F,N;75S;"UX.#9?-C0N<V\N,0!P87)?:6YI=%]E;G8`
M<&%R7V-U<G)E;G1?97AE8P!M>5]P87)?<&P`<&%R7V5N=E]C;&5A;@!P87)?
M9&ER;F%M90!P87)?9FEN9'!R;V<`<&%R7V1I90!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`>'-?:6YI=`!?<W1A<G1?8P!S:&%?=7!D871E`'!A<E]M:W1M<&1I
M<@!P87)?8VQE86YU<`!?7V)S<U]S=&%R=`!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`7V5D871A`%]E;F0`<&%R7V)A<V5N86UE
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'-H85]I;FET`'-H85]F:6YA
M;``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``````V+L````````(
M`````````(`C````````X+L````````(`````````"`C````````Z+L`````
M```(`````````#]A````````\+L````````(`````````-I@````````^+L`
M```````(`````````/=@`````````+P````````(`````````%!A````````
M`,`````````(``````````#`````````&,`````````(`````````.AB````
M````$+X````````&`````0``````````````&+X````````&`````@``````
M````````(+X````````&`````P``````````````*+X````````&````!```
M````````````,+X````````&````!0``````````````.+X````````&````
M!@``````````````0+X````````&````!P``````````````2+X````````&
M````"```````````````4+X````````&````"0``````````````6+X`````
M```&````"@``````````````8+X````````&````"P``````````````:+X`
M```````&````#```````````````<+X````````&````#0``````````````
M>+X````````&````#@``````````````@+X````````&````#P``````````
M````B+X````````&````$```````````````D+X````````&````$0``````
M````````F+X````````&````$@``````````````H+X````````&````$P``
M````````````J+X````````&````%```````````````L+X````````&````
M%0``````````````N+X````````&````%@``````````````P+X````````&
M````%P``````````````R+X````````&````&```````````````T+X`````
M```&````&0``````````````V+X````````&````&@``````````````X+X`
M```````&````&P``````````````Z+X````````&````'```````````````
M\+X````````&````'0``````````````^+X````````&````'@``````````
M`````+\````````&````'P``````````````"+\````````&````(```````
M````````$+\````````&````(0``````````````&+\````````&````(@``
M````````````(+\````````&````(P``````````````*+\````````&````
M)```````````````,+\````````&````)0``````````````.+\````````&
M````)@``````````````0+\````````&````)P``````````````2+\`````
M```&````*```````````````4+\````````&````*0``````````````6+\`
M```````&````*@``````````````8+\````````&````*P``````````````
M:+\````````&````+```````````````<+\````````&````+0``````````
M````>+\````````&````+@``````````````@+\````````&````+P``````
M````````B+\````````&````,```````````````D+\````````&````,0``
M````````````F+\````````2````,@``````````````H+\````````&````
M,P``````````````J+\````````&````-0``````````````L+\````````&
M````-@``````````````N+\````````&````-P``````````````P+\`````
M```&````.```````````````R+\````````&````.0``````````````T+\`
M```````&````.@``````````````V+\````````&````.P``````````````
MX+\````````&````/```````````````Z+\````````&````/0``````````
M````\+\````````&````/@``````````````^+\````````&````/P``````
M````````"+P````````%````5@``````````````(,`````````%````4P``
M````````````*,`````````%````7P``````````````"+X````````'````
M-```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!06,,`````````````````_S7BG0``_R7DG0``#Q]``/\EXIT``&@`````
MZ>#___\`````````````````````#PL/"V8N#Q^$``````!F+@\?A```````
M#Q^$``````!54TB#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`AD2(L4)2@`
M``!(B50D*$B-5"0(_Q4YG@``2(LUFIX``$B+/8N=``!(B?+_%?*>``"`/7.?
M````#X0A`0``2(L%UIX``&1(BP"`B#H$```#BT0D'(UX!(U8`TAC_TC!YP/_
M%>R>``!(BWPD$$2+1"0<2(G!2(D%J)\``$B+!TB)`4B-!=-```!(B4$(2(L%
M")\``$B)01!(C07`0```2(E!&$&#^`$/CC$!``!(@\<(08/``[H$````9BX/
M'X0``````$B+!TAC\H/"`4B#QPA(B03Q1#G"=>I(8])%,<!(BSU%GP``2(TU
MA@<``$C'!-$`````B=K_%2:=``"%P`^$C````$B+/1^?``!(C6PD)/\5Q)T`
M`$B)[DB-/?8^``")PS'`Z!D"``!(A<!T=$B+/?6>``#_%2^>``#_%0F>``!(
MBT0D*&1(*P0E*`````^%G````$B#Q#B)V%M=P_\5EIT``$B)!;^>``!(B<=(
MA<!T<_\5@9P``$B+!9J=``!D2(L0QH+V"````.FT_O__2(L]DYX``/\5[9P`
M`.EB____2(L]<9X``$B%_W0*Z#\=``#I=O___TB-/0P^``!(B>[H>P$``$B)
M!4R>``!(B<=(A<`/A%3____KTKH$````Z?+^__^_`0```/\5(9T``/\5(YP`
M`$@Q[4B)YTB--8Z9``!(@^3PZ`````"+-TB-5PA,C04#.0``13')2(T-7OW_
M_TB-/;?]___I<OW__V:02(T]:9T``$B-!6*=``!(.?AT%4B+!5:<``!(A<!T
M"?_@#Q^``````,,/'X``````2(T].9T``$B--3*=``!(*?Y(B?!(P>X_2,'X
M`T@!QDC1_G042(L%S9L``$B%P'0(_^!F#Q]$``###Q^``````(`]&9T```!U
M1U5(@STFFP```$B)Y70-2(L]PIP``/\5%)L``.AG____2(,]=YL```!T#4B-
M/79^``#_%6B;``#&!=F<```!7<,/'X``````PV9F+@\?A```````#Q]``$B#
M/5B<````="952(TUSIP``$B-/3=^``!(B>7_%3Z<``!=Z3C___\/'X0`````
M`.DK____9BX/'X0``````)!!5T%6055!5%532(/L"$R+-4N<``!-A?8/A)0`
M```/M@=)B?])B?6$P'0$/#UU444QY$F+'DB%VW0M36/D3(GU3(GB3(G^2(G?
M_Q7AF@``A<!U!T*`/",]=$9(BUT(2(/%"$B%VW792(/$"$B)V%M=05Q!74%>
M05_##Q^``````$F)_$$/MD0D`4F#Q`&$P'0$/#UU[D4I_.N89@\?1```3"GU
M2HU<(P%(P?T#08EM`.NU,=OKL68N#Q^$``````!32('LH````&1(BQPE*```
M`$B)G"28````2(G[2(GF_Q4[F@``A<!U-XM4)!B!X@#P``"!^@!```!T"('Z
M`*```'4?O@(```!(B=__%:^:``"%P`^4P`^VP.L'#Q]$```QP$B+E"28````
M9$@K%"4H````=0E(@<2@````6\/_%929``!F9BX/'X0``````)!!54%455-(
M@>RH````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G[=2M(BX0DF```
M`&1(*P0E*`````^%(P$``$B!Q*@```!;74%<05W#9@\?1```_Q72F0``2(G%
M2(7`=,=(B>__%0F9``!(A<`/A*@```"`>!,N3(U@$W4.08!\)`$`=-QF#Q]$
M``"`>!,N#X2F````2(G?_Q7UF0``3(GG28G%_Q7IF0``08U\!0)(8___%:.8
M``!,B>%(B=I(C34F.@``28G%2(G',<#_%7B9``!,B>](B>;_%7R9``!,B>^#
M^/]T$(M$)!@E`/```#T`0```=&3_%>:8``!,B>__%=V9``!(B>__%628``!(
MA<`/A5O___\/'P!(B>__%8>9``!(B=__%3Z8``#I]O[__V8/'X0``````$&`
M?"0!+@^%3O___T&`?"0"``^$#O___^D]____#Q\`Z)O^___KF_\5&Y@```\?
M`$%7,<!!5D%505154TB)^TB#["B`/CUD2(LL)2@```!(B6PD&$B)]0^4P$@!
MQ4B)[_\5\I@``$B-="042(G?28G$,<#H^/S__TB%P`^$)P$``$F)Q4B)Q_\5
MRY@``$PYX`^#\@```$QC="042<'F`P^V`X3`#X3.`0``/#T/A,8!``!(B=AF
M9BX/'X0``````&9F+@\?A```````#Q]$```/ME`!2(/``832=`6`^CUU[T@I
MV$B83(LMXY@``$J-?"`"_Q4HEP``30'U28E%`$B%P'1=2(L%Q9@``$B-2P%*
MBQ0P#[8#B`(\/70IA,!U%.LC9F8N#Q^$```````/'P`\/701#[8!2(/"`4B#
MP0&(`H3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$
M)2@````/A1<!``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BSTAF```28,_``^$Q@```$R)^$4Q[69F+@\?
MA```````9@\?1```2(/`"$2)ZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP5/F```
MA<!U6\<%09@```$```!(B??_%1B6``!(A<`/A%#___]-8_5(B40D"$R)_DB)
MQTG!Y@-,B?+_%:25``!(BTPD"$B)#9B7``!!C44!1(EL)!1(F$C'!,$`````
MZ4_^__],B?__%5>6``!(B05PEP``2(G!2(7`#X3U_O__36/U2<'F`^O##Q\`
M,<#I9_[__[X0````13'MZ5______%;:5``!F9BX/'X0```````\?`%-(BQV@
ME@``2(T-87<``$B--0`W``!(BQ4CE@``9$B+._\5J94``$R-!9<X``!D2(L[
M6T4QR4R)P4B-%>`3``!(C37K-@``_R4KE0``#Q\`2(L%498``$B+%>*5``!(
MC0T+=P``2(TUJC8``&1(BSC_)5J5``!F+@\?A```````55-(@>P`$```2(,,
M)`!(@>P`$```2(,,)`!(@^PH9$B+!"4H````2(F$)!@@```QP/\5D90``$R-
M!8DV``"^`1```$B)YXG!2(T5?#8``#'`_Q5AE```@_C_#X3`````2)A(/0`0
M```/AV+V__](C:PD$!```+H`$```2(GG2(GN_Q59E```2(G#A<`/B(X```"-
M>`%(8___%6*4``!(B<%(A<!T>DACVT@YZ',-2(T$&$@YQ0^"%?;__T@YS7)(
M2('[`1````^'`_;__TB)STB)VDB)[O\5]),``,8$&`!(B<%(BX0D&"```&1(
M*P0E*````'4N2('$*"```$B)R%M=PP\?1```2(U$'0!(.<%SKNFY]?__9@\?
MA```````,<GKO_\5_I,``&8/'T0``.G+_O__9F8N#Q^$``````!!5T%6055!
M5%532('L`!```$B##"0`2('LN````&1(BP0E*````$B)A"2H$```,<!)B?Q(
MB?-(C3U<-0``2(UT)`SHR?C__[XO````3(GG2(G%_Q6PE```2(7`=$,QP$R)
MYDB-/3DU``#H8OO__TR)X$B+E"2H$```9$@K%"4H````#X6Q`0``2('$N!``
M`%M=05Q!74%>05_#9@\?1```2(G?3(TM!34``$R--0DV``#_%<&3``!,B>Y(
MB<?_%9V3``!(B<-(A<!TDH`[``^$\@```&9F+@\?A```````D$B%[7042(G>
M2(GO_Q6GDP``A<`/A*T```!(B=__%?:3``!(C50#_TF)QT@YTW(MZSQF9BX/
M'X0``````&9F+@\?A```````9@\?A```````Q@(`2(/J`4@YTW0%@#HO=.](
MB=__%:Z3``!)B<=,B>?_%:*3``!)C40'`4@]_P\```^']O[__TR-O"2@````
M38GA2(G9,<!,C04S-```3(GRO@`0``!,B?__%>F1``"#P`$]`!```'9/#PL/
M'T0``(!]`0!U*TR)[C'__Q6OD@``2(G#2(7`#X2@_O__@#L`#X4:____2(7M
M=`:`?0`N=,]!OP$```!(C1VY,P``Z6K___\/'T0``$B-="003(G__Q7*D@``
MA<!UK(M$)"@E`/```#T`@```=9R^`0```$R)__\5N)(``(7`=8I,B?Y(C3U\
M,P``Z*7Y__],B?__%422``#I./[___\5J9$``)!3OB\```!(B?O_%:F1``!(
MC5`!2(7`2`]%VDB)WUO_)122``!F9BX/'X0``````)!54TB![``0``!(@PPD
M`$B#[!AD2(L$)2@```!(B80D"!```#'`2(7_#X2B````@#\`2(G]#X26````
M_Q5(D@``2(/``4@]`!````^'N````$B)[DB)YTB)X_\5D9```$B)Y_\5()(`
M`$B-1`3_2#G$<AKK'69F+@\?A```````D,8``$B#Z`%(.=AT!8`X+W3OOB\`
M``!(B=__%>F0``!(A<!T+$@YPW)72(G?_Q56D0``2(N4)`@0``!D2"L4)2@`
M``!U1TB!Q!@0``!;7<.02(N$)`@0``!D2"L$)2@```!U*4B!Q!@0``!(C3TV
M,@``6UW_)0^1```/'X``````Q@``ZZ0/'P`QP.NF_Q5FD```9F8N#Q^$````
M```/'P!!5T%6055!5%5(C2T3,@``4TB#[!AD2(L<)2@```!(B5PD"$B-7"0$
M#Q^$```````QP$B)WDB)[^A#]?__2(7`=#9(8U0D!$B+!9*1``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C2VM,0``D#'`
M2(G>2(GOZ//T__](A<!T-DAC5"0$2(L%0I$``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-+64Q``"0,<!(B=Y(B>_HH_3_
M_TB%P'0V2&-4)`1(BP7RD```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(
MB1!(A=)U\.N^9@\?1```2(TM'C$``)`QP$B)WDB)[^A3]/__2(7`=#9(8U0D
M!$B+!:*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF
M#Q]$``!(C2W5,```D#'`2(G>2(GOZ`/T__](A<!T-DAC5"0$2(L%4I```$B-
M!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-)94P
M``"0,<!(B=Y,B>?HL_/__TB%P'0V2&-4)`1(BP4"D```2(T$T$B+4`A(B1!(
MA=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE^B\``)`QP$B)WDR)
MY^AC\___2(7`=#9(8U0D!$B+!;*/``!(C0302(M0"$B)$$B%TG329I!(BU`0
M2(/`"$B)$$B%TG7PZ[YF#Q]$``!,C34!,```D#'`2(G>3(GWZ!/S__](A<!T
M-DAC5"0$2(L%8H\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72
M=?#KOF8/'T0``$R-+;LO``"0,<!(B=Y,B>_HP_+__TB%P'0V2&-4)`1(BP42
MCP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```
M3(T]=2\``)`QP$B)WDR)_^AS\O__2(7`=#9(8U0D!$B+!<*.``!(C0302(M0
M"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C3W#+@``D#'`
M2(G>3(G_Z"/R__](A<!T-DAC5"0$2(L%<HX``$B-!-!(BU`(2(D02(72=-)F
MD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B)WDB-/=PN``#HV?'__TB%P'0-
M2(G&3(GO,<#HA_3__S'`2(G>2(T]RBX``.BV\?__2(7`=!%(B<9(C3W(+@``
M,<#H8/3__TB)WDB-/<(N```QP.B/\?__2(G&2(7`=#E,B><QP.@]]/__2(M$
M)`AD2"L$)2@```!U1$B#Q!A(B>](C36L+@``,<!;74%<05U!7D%?Z0[T__\Q
MP$B)WDB-/7XN``#H/?'__TB%P'2[2(G&3(GW,<#HZ_/__^NL_Q7[BP``#Q\`
M2(/L&$B-/?4M``!D2(L$)2@```!(B40D"#'`2(UT)`3H^_#__TB%P'0N#[80
M@/HP#Y3`A-(/E,()T(/P`0^VP$B+5"0(9$@K%"4H````=0Q(@\08PP\?`#'`
MZ^3_%9:+``!F9BX/'X0```````\?`%!82('LV````$B)="0H2(E4)#!(B4PD
M.$R)1"1`3(E,)$B$P'0W#RE$)%`/*4PD8`\I5"1P#RF<)(`````/*:0DD```
M``\IK"2@````#RFT)+`````/*;PDP````&1(BP0E*````$B)1"08,<!(C80D
MX````$B)_DB)XDB)1"0(2(U$)"!(BSULB```QP0D"````,=$)`0P````2(E$
M)!#_%3J,``"__P```/\5SXL``&9F+@\?A```````#Q]``$%455-,C9PD``#_
M_TB![``0``!(@PPD`$PYW'7O2(/L$+H"````,?9D3(LD)2@```!,B:0D"``!
M`$&)_$B)X_\5>XH``$B-:/](B>I(P?H_2,'J,$B-1!4`#[?`2"G02"G%#XB\
M````#Q^$```````QTDB)[D2)Y_\50HH``$B#^/\/A+,```"Z"``!`$B)WD2)
MY_\5?XH``(/X_P^$BP```$B82(/X!W9F2(U$`_A(.=AR7$B-%7V+``#K'&9F
M+@\?A```````#Q^$``````!(@^@!2#G8<C=(BPA(.0IU[T@IV$@!Z$B+E"0(
M``$`9$@K%"4H````=4](@<00``$`6UU!7,-F+@\?A```````2('M```!`$B!
M_0``__\/A4S___](Q\#_____Z[I(C3T8+```,<#H!?[__TB-/?TK```QP.CW
M_?___Q5YB0``D$B#[`C_%3:)``")Q_\5'HH``$B%P'0#2(L`2(/$",.0055!
M5$R-)=TK``!52(G]3(GG4TB#[!AD2(L$)2@```!(B40D"#'`2(UT)`3H3^[_
M_TB%P'0(@#@`2(G#=2I(BT0D"&1(*P0E*````'5Q2(GN2(/$&$R)YS'`6UU!
M7$%=Z=OP__\/'P!(B>__%?>)``!(B=])B<7_%>N)``!)C7P%`O\5J(@``$F)
MV$B)ZDB-#8HJ``!)B<5(B<=(C36(*P``,<#_%7:)``!(BT0D"&1(*P0E*```
M`'4%3(GNZY+_%9.(``!F9BX/'X0``````$%72(T%+BH``$%69D@/;LA(C04=
M*P``055F2`]NT$B-!1<K``!!5&9(#V[82(T%$BL``%5F2`]NX#'`4TB!['@!
M``#S#WX%C84``&1,BSPE*````$R)O"1H`0``28G_2(UL)!Q(C3W.*0``2,=$
M)#``````2,=$)%``````9@]LP4B)[@\I1"0@\P]^!4^%``!(QX0DB```````
M``!F#VS"#Q%$)&CS#WX%.H4``&8/;,,/$40D>/,/?@4QA0``9@]LQ`\I1"1`
MZ./L__](A<!T#(`X`$B)PP^%D@0``/\5;(<``(G'_Q54B```2(7`#X3;`P``
M3(LH387M#X3/`P``3(GO_Q6.B```2(U\``'_%4N'``!!#[95`$B)!"1)B<:$
MTG0M3(TE(BH```\?0`!)@\4!#[;23(GW3(GF,<!)@\8"_Q4'B```00^V50"$
MTG7>3(UL)&!(C3US*0``ZPU)BWT(28/%"$B%_W1#2(GN,<#H.>S__TF)Q$B%
MP'3A@#@`=-Q(B<?HY.S__X7`=-!,B>?_%7^'``!(B<-(A<!U1&9F+@\?A```
M````#Q]``$R-9"0@28L<)$B%VW0G@#L`#X3Y`@``2(G?Z*'L__^%P`^%^0``
M`$F+7"0(28/$"$B%VW792(G?_Q6JAP``3(LT)$F)Q$R)]_\5FH<``$&-A`0$
M!```3&/@3(GG_Q5.A@``38GQ3(TU-2@``$B)VDF)Q4B)QTB--2PI```QP$R-
M!1XI``!,B?'_%1*'``"^P`$``$R)[_\5?(<``(/X_W43_Q4AAP``1(L`08/X
M$0^%XP(``$B-M"20````3(GO_Q5;A@``B<.%P'1U28L72(L]<X,``$R)Z3'`
M2(TU?RD``/\5$88``$4QY&8/'T0``$B+A"1H`0``9$@K!"4H````#X4I!```
M2('$>`$``$R)X%M=05Q!74%>05_##Q]``$B)WTF#Q`C_%3N&``!(B<-(A<`/
MA,S^___I]_[__V:0BX0DJ````"4`\```/0!````/A73___^+A"2L````B00D
M_Q4YA0``.00D#X5;____BX0DJ````"7_`0``/<`!```/A43___],B>?_%2"%
M``!(B>Y(C3W9)P``28G$,<#H7.K__TB%P`^$4P(``$F+/TB)QN@X\?__2(D$
M)$B%P`^$.P(``$B+/"3_%1F&``!(B<*#^`-^24B+#"1(F$B)5"0(2(TUR"<`
M`$B-?`'\_Q64A0``A<!U*$B+5"0(@_H$#X3H`@``2(L,)(U"^TB8@#P!+P^$
MU0(```\?@`````!(B>Y(C2VV)@``,<!(B>_HS.G__TB%P`^$TP$```^V`(3`
M#X3(`0``/#`/A,`!``!(B>](C37S)@``,<#H7^S__TR-/8TG``!(C2UT)P``
M_Q4#A```3(GQ3(GJ3(GG08G`3(T-;2<``$B--48G```QP/\5"84``.L]#Q^`
M`````/\5(H4``(,X$74^_Q7'@P``@\,!2(/L"$R)ZD%708G`08G93(GQ2(GN
M3(GG,<#_%<R$``!86K[``0``3(GG_Q4TA0``@_C_=+=,B>__%4:%``!,B>9(
MC3V-)0``,<#HO>O__TR)Y^AU^O__Z>#]__\QV^D>_?__9@\?A```````2(U<
M)$!F9BX/'X0``````$B+.TB%_W0D2(GN,<#HONC__TB)QTB%P'0%@#@`=3%(
MBWL(2(/#"$B%_W7<OPT```!,C2T0)@``_Q5"@P``NE,```!(B00D28G&Z?;[
M__^0_Q7B@P``2(/#"$F)Q4B%P'2>Z;K[__])BQ=(BSVG@```3(GI,<!(C35S
M)@``_Q5%@P``Z2_]__\/'X0``````$B)Q^BX^?__2(N$)&@!``!D2"L$)2@`
M```/A5$!``!(@<1X`0``2(G?6UU!7$%=05Y!7_\E;X,```\?@`````!)BP=(
MB00DZ;G]__\/'T``2(L\)#'V,<#_%=*#``!!B<>%P`^$)_[__XG'Z.#W__](
MA<`/B!?^__\QTDB-</9$B?](B00D_Q6$@@``2(VT)"H!``"Z!@```$2)__\5
MQH(``$B+#"1(@_@&#X7&````@;PD*@$```!#04,/A<_]__]F@;PD+@$``$A%
M#X6__?__2(V<)#`!```QTDB-<<Y$B?__%2B"``"Z*````$B)WD2)__\5;X(`
M`$B#^"AU=\:$)%@!````28G83(GQ,<!,C0T?)0``3(GJ2(TUYB0``$R)Y_\5
MMX(``.G[_?__38M_"$V%_P^$)?W__TR)__\5Y((``$B#^`,/AA+]__])C7P'
M_$B--9PD``#_%6B"``"%P$P/13PD3(D\).GP_/___Q6B@0``2(T]?B0``#'`
MZ`SV__]F9BX/'X0``````)!!54B-/6LC``!!5%532(/L&&1(BQPE*````$B)
M7"0(2(L=8H(``$R-9"0$3(GF9$B+*P^VA;````"(A;$````QP.AJYO__2(7`
M=`F`.#$/A&P!```QP.C5\/__9$B+*TB)[[D#````N@$```!(C34Q)```_Q7?
M@0``2(G%2(7`="E(BT`09$B+.TB-%18D``!(BS#_%0>!``!(BT402(LP]D8.
M0`^%5@$``&1(BSNY`P```+H!````2(TU[",``/\5DX$``$B)Q4B%P'0N3(GF
M2(T]:R(``#'`Z-+E__](B<)(A<`/A.8```!(BT409$B+.TB+,/\5I8```&1(
MBSNZ`0```$B--:(C``#_%?>```!D2(L[2(T5IB,``$B)QO\5>X```&1(BP-(
MC3T)(@``3(GFQH"Q`````#'`Z&_E__](B05`@@``2(G'2(7`=$"^P`$``/\5
M;8$``(U0`8/Z`78)@_@1#X6C````2(M$)`AD2"L$)2@````/A<T```!(@\08
M6UU!7$%=PP\?1```2(L]^8$``.AD]___2(D%Y8$``$B)QTB%P'6E2(T]MB,`
M`#'`_Q5.?P``9@\?1```@'@!``^$E?[__^F%_O__D.B+ZO__9$B+.TF)Q4B+
M11!(BS!-A>UT4$R)ZO\5KW\``$R)[_\5[H```.G\_O__D&1(BSO_%2Y_``#I
MF_[__XG!2(L%>($``$B+%6F!``!(C3UJ(P``2(LP,<#_%==^```/'X``````
M2(L%48$``$B+$/\56'\``.FN_O___Q4U?P``9F8N#Q^$``````!FD%532(G[
M2(T])"$``$B#[!AD2(L$)2@```!(B40D"#'`2(UT)`3H)N3__TB%P'0<#[80
MA-(/E,"`^C`/E,((T'4*2(7;=`6`.P!U'4B+1"0(9$@K!"4H````=7%(@\08
M6UW#9@\?1```2(G?Z$#M__^^+P```$B)Q4B)Q_\5MWX``$B-4`%(A<!(#T7J
M2(GO_Q4C?P``N@0```!(C352(0``2(G'_Q76?@``A<!UG4B+1"0(9$@K!"4H
M````=0Y(@\082(G?6UWIU.3___\55GX``&8N#Q^$```````/'T``05=!5D%5
M05154TB![)@"``!D2(LT)2@```!(B;0DB`(``$B)_DB)XDR-C"2`````2(GG
M3(U&.&8/'X0``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,B=!(P>D@
M2,'H*$G!ZC@E`/\``$P)T$F)RDC!X0A)P>(8@>$``/\`18G23`G02`G(2(E'
M^$PYSW6MN_____]F#V]$)!!(C40D:&8/;UPD(&9(#V[K9@]O5"0P2('":`(`
M`&8/;.V0\P]O"&8/;^)F#V]0V$B#P!!F#^]`B&8/[\IF#^_!9@]OR&8/<_`!
M9@]ST1]F#^O!9@_;Q0\I0`AF#V_#9@]OW$@YT'6[3(L.3(M>$$B+?B!(BUX8
M3(G(3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY@EI,
MB=A(,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!B=!,
M,<!,(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!X!Y/
MC903F7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD
M&$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G![1M(
M,<A,`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):
M3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'13(G2
M2<'J`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)
MSTC!YP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"
M2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(P>(>
M18GD3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%30GJ
M3(ML)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M&XG'
M3"'B2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*C8PI
MF7F"6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML)%`!
MP4R)T$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),,>)(
M`?I(B<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)PDF)
M_4@QT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(P>`>
M2,'I`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB2<'B
M!4T)ZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT$G!
M[1N)UTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>18G`
M2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+
M;"1X`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`
M3#'@2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD+)EY
M@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(B<I(
MP>D"3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,,<!,
M`=!-B>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9>8):
M2`GX38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)Z$G!
M[0))P>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G![1M(
M`<A,B>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQRD0Q
MTDR+E"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'73(GB
M2,'B'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-C:0`
MH>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$F)
MU8G22`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)
M`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP````(G)
M23'02`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(
MB?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9;DR)
MP4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$
M)-@```!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))
MP>@"2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)T$V)
MT$G!Z!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4).@`
M``!(,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"
M2,'A'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)^DG!
MZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL
M`*'KV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"2,'@
M'D6)Z$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(
MP>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!),<I%
M,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)
MZDP)PDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#C"00
M`0``B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$,>],
MC:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)
MT4F)PHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2
MB=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)^$B)
MUXG22`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG38G4
M2<'J`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-E!*A
MZ]EN2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)Y$DQ
MT$F)UD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY2,'O
M`KC<O!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-B<1,
M`?)-B<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G2
M22'^3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)
MUD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!``!)
M`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)
MT4F)UD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N&TG!
MX@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+
MM"1@`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"2,'B
M'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,`>%-
MB<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.32'&
M3"'23`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)
MPDC!XAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)`<9,
M`?=-B>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)X4&)
MS$D)SDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!X@5-
M"?)!`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+M"2(
M`0``20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"2,'A
M'D6)P$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-B<1)
MP>X;2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!
M3`GQ3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)
MP4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,`?=-
MB>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)
MU$TAQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))
MB=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P`0``
M20'&30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)P$@)
M^D@)T4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)P>X;
M2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'23`GR
M3(NT),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!Z`)(
MP>(>18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-B>A(
M`?E,B>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)^4PA
MZ4PAXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;2,'A
M!4P)T8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)"?U*
MC3PX3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H`DC!
MX!Y!B?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)P>P;
M2,'A!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0QYTR+
MI"3H`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F'D6)
MY$T)]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'03(GB2<'N
M&TC!X@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y3(N\
M)``"``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!
MX1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G12<'M
M&TD!QTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)`<9,
M`?)-B>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!
MXAY!B?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR2<'L
M&TD!QTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)`<5,
M`>E-B=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!
MX1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI2<'J
M&TC!X05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)`<1,
M`>)-B?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M`DC!
MXAY!B?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB2<'N
M&TC!X@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),`=%-
MB>I),=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!
MX1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G12<'M
M&TC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,`?)-
MB>9%B>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!
MXAY!B?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'43(GR
M2<'H&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)`<5,
M`>E-B=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!
MX1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ2<'L
M&TG!X@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*20'$
M2`.$)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)XDV)
M[$G![0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!P$V)
MZ$P!X4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0QQTF)
MR$@!^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)T$C!
MZ@)(P>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'422('$F`(`
M`%M=05Q!74%>05_#_Q7=9P``#Q]$``!(@^P(OX````#_%:%G``!F#V\%F4D`
M`$C'0#``````#Q$`9@]O!99)``#'0'@`````#Q%`$&8/;P6320``#Q%`($B#
MQ`C#9BX/'X0``````$%72&/"28GW059)B?Y!54%428G$54F-;CA32(/L&$B+
M?RA)BU8PC0S'2#GY26-^>$F)3BA(@](`2,'H'4@!T$F)1C"%_W1O0;U`````
M28UN.$$I_44YY44/3^Q(`>])8]5(.?</@B8!``!(C1P62#G^<PE(.=\/@KD!
M``!,B?[_%:MF``!!BT9X1`'H08E&>(/X0'032(/$&%M=05Q!74%>05_##Q]`
M`$R)]T4I[$F)W^B*Z/__08/\/WY\28U&>$R)^TV-;T!(B40D".M09I!(BT0D
M"$@YPP^"7`$``$V)[_,/;P-,B?=!@^Q`2(/#0$F#Q4`/$44`\P]O0]`/$440
M\P]O0^`/$44@\P]O0_`/$44PZ"CH__]!@_P_?AI(.=URK4V)[T@YZW.V3#GM
M<['I_<?__P\?`$ECQ$PY_7)`23GO<PU)C10'2#G5#X+@Q___2(/X"'-8J`0/
MA<````!(A<`/A9<```!%B69X2(/$&%M=05Q!74%>05_##Q]``$B-5`4`23G7
M<\CIH\?__Y!(C0072#G&#X*5Q___2(T<%NG6_O__9BX/'X0``````$F+%TB-
M30A,B?Y(@^'X28E6.$F+5`?X2(E4!?A(*<U(`>A(*>Y(@^#X2(/X"'**2(/@
M^#'22(L\%DB)/!%(@\((2#G"<N_I;O___P\?1```00^V%T&(5CBH`@^$6?__
M_T$/MU0'_F:)5`7^Z4G___]!BQ=!B58X08M4!_R)5`7\Z33____I^,;__^GS
MQO__D$%63(UV.$%505152(G]4TR+;BA(B?-,BV8P3(GH2,'H`X/@/XU(`<9$
M!CB`2&/!3`'P@_DX#XY]`0``ND`````IRG0/,<F)SH/!`<8$,``YT7+S2(G?
MZ*7F__]F#^_`#Q%#.$G'1C``````00\11A!!#Q%&($R)XD$/ML5-B>A,B>](
MP>H82,'@"$R)X4G!Z!!)B=%,B>I(P>\8#[;V3(GB2,'I$$@)\$$/MO`/MLE(
MP>`(2`GP0`^V]TB)WTC!X`A("?!!#[;T2,'@"$@)\`^V]D$/MM%(P>`(2`GP
M2,'@"$@)R$C!X`A("=!(B4-PZ`SF__](BP-(B=](P>@8B$4`2(L#2,'H$(A%
M`4B+`XAE`DB+`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(B&4&2(M#
M"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,0B&4*2(M#$(A%"TB+0QA(
MP>@8B$4,2(M#&$C!Z!"(10U(BT,8B&4.2(M#&(A%#TB+0R!(P>@8B$402(M#
M($C!Z!"(11%(BT,@B&422(M#((A%$UM=05Q!74%>_R7S9```#Q\`NC@````Q
M]BG*@_H(<RKVP@1U;872#X2B_O__Q@``]L("#X26_O__,<EFB4P0_NF*_O__
M#Q]$``")T4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X):
M_O__@^+X,<")QX/`"$B)-#DYT'+SZ4/^__]F#Q]$``#'``````#'1!#\````
M`.DJ_O__4%C#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X
M`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE`"TM````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I
M.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F
M9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE
M(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN
M9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`]
M(#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P
M;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@
M("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW
M:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF
M("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*
M<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E
M='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P
M;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N
M9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F
M(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B
M*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@
M9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM
M>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F
M<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\[
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5]
M(#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP
M(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M
M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@
M)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F
M;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T
M(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L
M;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&
M24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC
M;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H
M(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A
M8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?
M;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L*
M*"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T
M:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#
M3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E
M;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@
M)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N
M86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H
M92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*
M?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E
M;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B
M)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI
M;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``0T%#2$4``'!E<FQX<VDN8P`````````!(T5G`````(FKS>\`
M````_MRZF`````!V5#(0`````/#ATL,````````````````!&P,[[````!P`
M``!P?___"`$``*!___^,`@``HG___V0&``#`?___:`4``""#__\P`0``X(/_
M_WP!``!PA/__H`$``."%___<`0``4(C__R@"``"@B/__1`(``-"(__]8`@``
M`(K__Z0"```0BO__N`(``%",__\(`P``@(S__R0#``"@C?__8`,```"2__^L
M`P``<)+__\@#```PD___Y`,``("4__\D!```H)3__SP$``!PE?__>`0``'"<
M___T!```T)[__S`%``"PG___F`4``""V___H!0``<+;__P`&``"PN/__A`8`
M```````4``````````%Z4@`!>!`!&PP'")`!```D````'````&!^__\@````
M``X01@X82@\+=PB``#\:.RHS)"(`````2````$0```#H@?__M@````!"#A"/
M`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`"70H..$0.,$$.*$(.($(.
M&$(.$$(."$@+`"````"0````7(+__X0`````00X0@P)'#K`!`G0*#A!!#@A!
M"S@```"T````R(+__VT!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.
M*$$.($$.&$(.$$(."$<+`$@```#P````_(/__V("````0@X0CP)$#AB.`T(.
M((T$0@XHC`5!#C"&!D$..(,'1PY@`S8!"@XX00XP00XH0@X@0@X80@X00@X(
M10L8````/`$``""&__]-`````$$.$(,"<@X(````$````%@!``!4AO__)@``
M```````P````;`$``'"&__\J`0```$$.$(8"00X8@P-'#I@@3`Z80$D.P$`"
MWPH.&$0.$$$."$8+%````*`!```,??__`@`````.P$"#`X8"$````+@!``!4
MA___!0````````!,````S`$``%"'__\_`@```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T<.N"!,#O`A`G(*#CA!#C!!#BA"#B!"#AA"#A!"#@A'
M"Q@````<`@``0(G__R0`````00X0@P)=#@@````X````.`(``%2)__\2`0``
M`$$.$(8"00X8@P-'#I@@20ZP(`*Z"@X800X000X(0@M:"@X82`X000X(30M(
M````=`(``#B*__]=!````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9(#CB#
M!T0.4`,"!`H..$T.,$$.*$(.($(.&$(.$$(."$4+&````,`"``!,CO__8@``
M``!$#B`"4`H."$0+`!@```#<`@``H([__[$`````00X000X(1P[@`0`\````
M^`(``$2/__]/`0```$(.$(P"00X8A@-!#B"#!$@,"Z"`!%$-!T0.L(`$`N`*
M#B!!#AA!#A!"#@A+"P``%````#@#``!4D/__'P````!$#A!:#@@`.````%`#
M``!<D/__Q0````!"#A"-`D(.&(P#2`X@A@1'#BB#!40.0'X*#BA&#B!!#AA"
M#A!"#@A("P``>````(P#``#PD/__]`8```!"#A"/`DD.&(X#3@X@C01.#BB,
M!4T.,(8&2`XX@P='#K`#`WL""@XX1`XP00XH0@X@0@X80@X00@X(10L#F`$.
MN`-%#L`#6`ZX`T$.L`,#$`$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P```#@`
M```(!```=)?__U,"````0@X0C0))#AB,`T$.((8$00XH@P5$#D`#<P$*#BA!
M#B!!#AA"#A!"#@A&"S0```!$!```F)G__](`````00X0A@)!#AB#`TX.,`)/
M"@X800X000X(1PL"6@H.&$0.$$$."$4++````'P$``!0>O__%0(```!!#A"&
M`D$.&(,#1`Y0`W$!"@X80PX000X(00L`````3````*P$```0FO__:Q8```!"
M#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`TD6"@XX00XP00XH
M0@X@0@X80@X00@X(00L````4````_`0``#"P__]&`````$0.$`)!#@A@````
M%`4``&BP__\_`@```$(.$(\"2`X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T0.
M4`)["@XX00XP00XH0@X@0@X80@X00@X(10L"R0H..$$.,$$.*$(.($(.&$(.
M$$(."$4+'````'@%```V>?__`@`````.4(,'A@:,!8T$C@./`@`\````F`4`
M`"2R__]+`@```$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#F0$*#BA!#B!"
M#AA"#A!"#@A)"P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````@",````````@(P```````#]A
M````````VF````````#W8````````%!A```````````````````!````````
M`-`"`````````0````````#;`@```````!T`````````#@0````````,````
M```````@````````#0````````";6P```````!D`````````V+L````````;
M``````````@`````````&@````````#@NP```````!P`````````"```````
M``#U_O]O`````)`#````````!0````````"(#0````````8`````````B`0`
M```````*`````````"P$````````"P`````````8`````````!4`````````
M```````````#`````````/"]`````````@`````````8`````````!0`````
M````!P`````````7`````````)`8````````!P````````"X$0````````@`
M````````V`8````````)`````````!@`````````'@`````````(````````
M`/O__V\``````0``"`````#Y__]O``````@`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````0O```````````````````````````
M```F(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P`````````I005(N<&T*``````````#H8@```````$=#
M0SH@*$%L<&EN92`Q-"XR+C`I(#$T+C(N,```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````!@#````````&`,````````9````````````
M`````````0```````````````````!,````'`````@`````````X`P``````
M`#@#````````,`````````````````````@````````````````````F````
M!P````(`````````:`,```````!H`P```````"0````````````````````$
M````````````````````.0```/;__V\"`````````)`#````````D`,`````
M``#T``````````4`````````"````````````````````$,````+`````@``
M``````"(!````````(@$``````````D````````&`````0````@`````````
M&`````````!+`````P````(`````````B`T```````"(#0```````"P$````
M```````````````!````````````````````4P````0````"`````````+@1
M````````N!$```````#8!@````````4`````````"``````````8````````
M`%T````$````0@````````"0&````````)`8````````&``````````%````
M%`````@`````````&`````````!G`````0````8``````````"``````````
M(`````````,````````````````````!````````````````````8@````$`
M```&`````````!`@````````$"`````````@````````````````````$```
M```````0`````````&T````!````!@````````!`(````````$`@````````
M6SL``````````````````"````````````````````!S`````0````8`````
M````FUL```````";6P````````,````````````````````!````````````
M````````>0````$````"``````````!@`````````&````````"@0```````
M````````````$````````````````````($````!`````@````````"@H```
M`````*"@````````[`````````````````````0```````````````````"/
M`````0````(`````````D*$```````"0H0```````-@%````````````````
M```(````````````````````F0````X````#`````````-B[````````V*L`
M```````(````````````````````"``````````(`````````*4````/````
M`P````````#@NP```````."K````````"`````````````````````@`````
M````"`````````"Q`````0````,`````````Z+L```````#HJP```````"@`
M```````````````````(````````````````````O@````8````#````````
M`!"\````````$*P```````#@`0````````8`````````"``````````0````
M`````,<````!`````P````````#PO0```````/"M````````$`(`````````
M``````````@`````````"`````````#,`````0````,``````````,``````
M````L````````"`````````````````````(````````````````````T@``
M``@````#`````````"#`````````(+````````"0````````````````````
M(````````````````````-<````!````,````````````````````""P````
M````'`````````````````````$``````````0`````````!`````P``````
M```````````````````\L````````.`````````````````````!````````
)````````````
